        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 21 <br>1,4,6,7,12,13,16,17,18,20,23,26,31,35,37,39,40,41,43,44,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 17 <strong>control</strong><br>0,2,3,5,10,11,19,21,22,25,28,29,33,36,46,47,48';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>45</strong> miembros: 8 <br>9,14,15,30,34,38,45,49';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260521 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>32</strong> miembros: 5 <br>8,24,27,32,42';}
}
